Versioning
==========

:obj:`salp`'s releases are versioned `major.minor.patch`.

- `patch` versions add features that are backwards-compatible and bug fixes.
- `minor` versions introduce larger changes that may be API-changing features and bug fixes.
- `major` versions ... we'll see when we get there.

Worried about API-changing updates?

You could set your requirements as `salp >= 0.x.y, < 0.x+1.0`, for example `salp >= 0.2.0, < 0.3.0`

